@@ -501,7 +501,10 @@ def find_host_info_PS1(df, fn, dict_fn, path, rad, append=0):
             # Save host info
             if not os.path.exists(path+ '/dictionaries/'):
             	os.makedirs(path+'/dictionaries/')
-            with open(path+"/dictionaries/" + dict_fn, 'wb') as fp:
+            option = "wb"
+            if append:
+                option = "ab"
+            with open(path+"/dictionaries/" + dict_fn, option) as fp:
                 pickle.dump(SN_Host_PS1, fp, protocol=pickle.HIGHEST_PROTOCOL)
 
 def find_host_info_SH(df, fn, dict_fn, path, rad):
