@@ -29,94 +29,96 @@ from datetime import datetime
 import astro_ghost
 from joblib import dump, load
 
-def getGHOST(real=False, verbose=False):
-    install_path = os.getenv('GHOST_PATH')
-    if not install_path:
-    	install_path = astro_ghost.__file__
-    	install_path = install_path.split("/")[:-1]
-   	install_path = "/".join(install_path)
-  	if not os.path.exists(install_path + '/database'):
-       		os.makedirs(install_path + '/database')
-        os.environ['GHOST_PATH'] = install_path
+def getGHOST(real=False, verbose=False, installpath=''):
+    if not installpath:
+        try:
+            installpath = os.environ['GHOST_PATH']
+        except:
+            print("Couldn't find where you want to save GHOST. Saving in package path...")
+            installpath = astro_ghost.__file__
+            installpath = installpath.split("/")[:-1]
+            installpath = "/".join(installpath)
+    if not os.path.exists(installpath + '/database'):
+        os.mkdir(installpath + '/database')
     if real:
         url = 'https://www.dropbox.com/s/a0fufc3827pfril/GHOST.csv?dl=1'
         r = requests.get(url)
-        fname = install_path + '/database/GHOST.csv'
+        fname = installpath + '/database/GHOST.csv'
         open(fname , 'wb').write(r.content)
         if verbose:
             print("Successfully downloaded GHOST database.\n")
     else:
         #create dummy database
         colnames = ['objName', 'objAltName1', 'objAltName2', 'objAltName3', 'objID',
-       'uniquePspsOBid', 'ippObjID', 'surveyID', 'htmID', 'zoneID',
-       'tessID', 'projectionID', 'skyCellID', 'randomID', 'batchID',
-       'dvoRegionID', 'processingVersion', 'objInfoFlag', 'qualityFlag',
-       'raStack', 'decStack', 'raStackErr', 'decStackErr', 'raMean',
-       'decMean', 'raMeanErr', 'decMeanErr', 'epochMean', 'posMeanChisq',
-       'cx', 'cy', 'cz', 'lambda', 'beta', 'l', 'b', 'nStackObjectRows',
-       'nStackDetections', 'nDetections', 'ng', 'nr', 'ni', 'nz', 'ny',
-       'uniquePspsSTid', 'primaryDetection', 'bestDetection',
-       'gippDetectID', 'gstackDetectID', 'gstackImageID', 'gra', 'gdec',
-       'graErr', 'gdecErr', 'gEpoch', 'gPSFMag', 'gPSFMagErr', 'gApMag',
-       'gApMagErr', 'gKronMag', 'gKronMagErr', 'ginfoFlag', 'ginfoFlag2',
-       'ginfoFlag3', 'gnFrames', 'gxPos', 'gyPos', 'gxPosErr', 'gyPosErr',
-       'gpsfMajorFWHM', 'gpsfMinorFWHM', 'gpsfTheta', 'gpsfCore',
-       'gpsfLikelihood', 'gpsfQf', 'gpsfQfPerfect', 'gpsfChiSq',
-       'gmomentXX', 'gmomentXY', 'gmomentYY', 'gmomentR1', 'gmomentRH',
-       'gPSFFlux', 'gPSFFluxErr', 'gApFlux', 'gApFluxErr', 'gApFillFac',
-       'gApRadius', 'gKronFlux', 'gKronFluxErr', 'gKronRad', 'gexpTime',
-       'gExtNSigma', 'gsky', 'gskyErr', 'gzp', 'gPlateScale',
-       'rippDetectID', 'rstackDetectID', 'rstackImageID', 'rra', 'rdec',
-       'rraErr', 'rdecErr', 'rEpoch', 'rPSFMag', 'rPSFMagErr', 'rApMag',
-       'rApMagErr', 'rKronMag', 'rKronMagErr', 'rinfoFlag', 'rinfoFlag2',
-       'rinfoFlag3', 'rnFrames', 'rxPos', 'ryPos', 'rxPosErr', 'ryPosErr',
-       'rpsfMajorFWHM', 'rpsfMinorFWHM', 'rpsfTheta', 'rpsfCore',
-       'rpsfLikelihood', 'rpsfQf', 'rpsfQfPerfect', 'rpsfChiSq',
-       'rmomentXX', 'rmomentXY', 'rmomentYY', 'rmomentR1', 'rmomentRH',
-       'rPSFFlux', 'rPSFFluxErr', 'rApFlux', 'rApFluxErr', 'rApFillFac',
-       'rApRadius', 'rKronFlux', 'rKronFluxErr', 'rKronRad', 'rexpTime',
-       'rExtNSigma', 'rsky', 'rskyErr', 'rzp', 'rPlateScale',
-       'iippDetectID', 'istackDetectID', 'istackImageID', 'ira', 'idec',
-       'iraErr', 'idecErr', 'iEpoch', 'iPSFMag', 'iPSFMagErr', 'iApMag',
-       'iApMagErr', 'iKronMag', 'iKronMagErr', 'iinfoFlag', 'iinfoFlag2',
-       'iinfoFlag3', 'inFrames', 'ixPos', 'iyPos', 'ixPosErr', 'iyPosErr',
-       'ipsfMajorFWHM', 'ipsfMinorFWHM', 'ipsfTheta', 'ipsfCore',
-       'ipsfLikelihood', 'ipsfQf', 'ipsfQfPerfect', 'ipsfChiSq',
-       'imomentXX', 'imomentXY', 'imomentYY', 'imomentR1', 'imomentRH',
-       'iPSFFlux', 'iPSFFluxErr', 'iApFlux', 'iApFluxErr', 'iApFillFac',
-       'iApRadius', 'iKronFlux', 'iKronFluxErr', 'iKronRad', 'iexpTime',
-       'iExtNSigma', 'isky', 'iskyErr', 'izp', 'iPlateScale',
-       'zippDetectID', 'zstackDetectID', 'zstackImageID', 'zra', 'zdec',
-       'zraErr', 'zdecErr', 'zEpoch', 'zPSFMag', 'zPSFMagErr', 'zApMag',
-       'zApMagErr', 'zKronMag', 'zKronMagErr', 'zinfoFlag', 'zinfoFlag2',
-       'zinfoFlag3', 'znFrames', 'zxPos', 'zyPos', 'zxPosErr', 'zyPosErr',
-       'zpsfMajorFWHM', 'zpsfMinorFWHM', 'zpsfTheta', 'zpsfCore',
-       'zpsfLikelihood', 'zpsfQf', 'zpsfQfPerfect', 'zpsfChiSq',
-       'zmomentXX', 'zmomentXY', 'zmomentYY', 'zmomentR1', 'zmomentRH',
-       'zPSFFlux', 'zPSFFluxErr', 'zApFlux', 'zApFluxErr', 'zApFillFac',
-       'zApRadius', 'zKronFlux', 'zKronFluxErr', 'zKronRad', 'zexpTime',
-       'zExtNSigma', 'zsky', 'zskyErr', 'zzp', 'zPlateScale',
-       'yippDetectID', 'ystackDetectID', 'ystackImageID', 'yra', 'ydec',
-       'yraErr', 'ydecErr', 'yEpoch', 'yPSFMag', 'yPSFMagErr', 'yApMag',
-       'yApMagErr', 'yKronMag', 'yKronMagErr', 'yinfoFlag', 'yinfoFlag2',
-       'yinfoFlag3', 'ynFrames', 'yxPos', 'yyPos', 'yxPosErr', 'yyPosErr',
-       'ypsfMajorFWHM', 'ypsfMinorFWHM', 'ypsfTheta', 'ypsfCore',
-       'ypsfLikelihood', 'ypsfQf', 'ypsfQfPerfect', 'ypsfChiSq',
-       'ymomentXX', 'ymomentXY', 'ymomentYY', 'ymomentR1', 'ymomentRH',
-       'yPSFFlux', 'yPSFFluxErr', 'yApFlux', 'yApFluxErr', 'yApFillFac',
-       'yApRadius', 'yKronFlux', 'yKronFluxErr', 'yKronRad', 'yexpTime',
-       'yExtNSigma', 'ysky', 'yskyErr', 'yzp', 'yPlateScale', 'distance',
-       'NED_name', 'NED_type', 'NED_vel', 'NED_redshift', 'NED_mag',
-       'i-z', 'g-r', 'r-i', 'g-i', 'z-y', 'g-rErr', 'r-iErr', 'i-zErr',
-       'z-yErr', 'gApMag_gKronMag', 'rApMag_rKronMag', 'iApMag_iKronMag',
-       'zApMag_zKronMag', 'yApMag_yKronMag', '7DCD', 'class', 'dist/DLR',
-       'dist', 'TransientClass', 'TransientRA', 'TransientDEC',
-       'TransientDiscoveryDate', 'TransientDiscoveryMag',
-       'TransientRedshift', 'TransientDiscoveryYear', 'Transient AltName',
-       'host_logmass', 'host_logmass_min', 'host_logmass_max',
-       'Hubble Residual', 'TransientName']
+            'uniquePspsOBid', 'ippObjID', 'surveyID', 'htmID', 'zoneID',
+            'tessID', 'projectionID', 'skyCellID', 'randomID', 'batchID',
+            'dvoRegionID', 'processingVersion', 'objInfoFlag', 'qualityFlag',
+            'raStack', 'decStack', 'raStackErr', 'decStackErr', 'raMean',
+            'decMean', 'raMeanErr', 'decMeanErr', 'epochMean', 'posMeanChisq',
+            'cx', 'cy', 'cz', 'lambda', 'beta', 'l', 'b', 'nStackObjectRows',
+            'nStackDetections', 'nDetections', 'ng', 'nr', 'ni', 'nz', 'ny',
+            'uniquePspsSTid', 'primaryDetection', 'bestDetection',
+            'gippDetectID', 'gstackDetectID', 'gstackImageID', 'gra', 'gdec',
+            'graErr', 'gdecErr', 'gEpoch', 'gPSFMag', 'gPSFMagErr', 'gApMag',
+            'gApMagErr', 'gKronMag', 'gKronMagErr', 'ginfoFlag', 'ginfoFlag2',
+            'ginfoFlag3', 'gnFrames', 'gxPos', 'gyPos', 'gxPosErr', 'gyPosErr',
+            'gpsfMajorFWHM', 'gpsfMinorFWHM', 'gpsfTheta', 'gpsfCore',
+            'gpsfLikelihood', 'gpsfQf', 'gpsfQfPerfect', 'gpsfChiSq',
+            'gmomentXX', 'gmomentXY', 'gmomentYY', 'gmomentR1', 'gmomentRH',
+            'gPSFFlux', 'gPSFFluxErr', 'gApFlux', 'gApFluxErr', 'gApFillFac',
+            'gApRadius', 'gKronFlux', 'gKronFluxErr', 'gKronRad', 'gexpTime',
+            'gExtNSigma', 'gsky', 'gskyErr', 'gzp', 'gPlateScale',
+            'rippDetectID', 'rstackDetectID', 'rstackImageID', 'rra', 'rdec',
+            'rraErr', 'rdecErr', 'rEpoch', 'rPSFMag', 'rPSFMagErr', 'rApMag',
+            'rApMagErr', 'rKronMag', 'rKronMagErr', 'rinfoFlag', 'rinfoFlag2',
+            'rinfoFlag3', 'rnFrames', 'rxPos', 'ryPos', 'rxPosErr', 'ryPosErr',
+            'rpsfMajorFWHM', 'rpsfMinorFWHM', 'rpsfTheta', 'rpsfCore',
+            'rpsfLikelihood', 'rpsfQf', 'rpsfQfPerfect', 'rpsfChiSq',
+            'rmomentXX', 'rmomentXY', 'rmomentYY', 'rmomentR1', 'rmomentRH',
+            'rPSFFlux', 'rPSFFluxErr', 'rApFlux', 'rApFluxErr', 'rApFillFac',
+            'rApRadius', 'rKronFlux', 'rKronFluxErr', 'rKronRad', 'rexpTime',
+            'rExtNSigma', 'rsky', 'rskyErr', 'rzp', 'rPlateScale',
+            'iippDetectID', 'istackDetectID', 'istackImageID', 'ira', 'idec',
+            'iraErr', 'idecErr', 'iEpoch', 'iPSFMag', 'iPSFMagErr', 'iApMag',
+            'iApMagErr', 'iKronMag', 'iKronMagErr', 'iinfoFlag', 'iinfoFlag2',
+            'iinfoFlag3', 'inFrames', 'ixPos', 'iyPos', 'ixPosErr', 'iyPosErr',
+            'ipsfMajorFWHM', 'ipsfMinorFWHM', 'ipsfTheta', 'ipsfCore',
+            'ipsfLikelihood', 'ipsfQf', 'ipsfQfPerfect', 'ipsfChiSq',
+            'imomentXX', 'imomentXY', 'imomentYY', 'imomentR1', 'imomentRH',
+            'iPSFFlux', 'iPSFFluxErr', 'iApFlux', 'iApFluxErr', 'iApFillFac',
+            'iApRadius', 'iKronFlux', 'iKronFluxErr', 'iKronRad', 'iexpTime',
+            'iExtNSigma', 'isky', 'iskyErr', 'izp', 'iPlateScale',
+            'zippDetectID', 'zstackDetectID', 'zstackImageID', 'zra', 'zdec',
+            'zraErr', 'zdecErr', 'zEpoch', 'zPSFMag', 'zPSFMagErr', 'zApMag',
+            'zApMagErr', 'zKronMag', 'zKronMagErr', 'zinfoFlag', 'zinfoFlag2',
+            'zinfoFlag3', 'znFrames', 'zxPos', 'zyPos', 'zxPosErr', 'zyPosErr',
+            'zpsfMajorFWHM', 'zpsfMinorFWHM', 'zpsfTheta', 'zpsfCore',
+            'zpsfLikelihood', 'zpsfQf', 'zpsfQfPerfect', 'zpsfChiSq',
+            'zmomentXX', 'zmomentXY', 'zmomentYY', 'zmomentR1', 'zmomentRH',
+            'zPSFFlux', 'zPSFFluxErr', 'zApFlux', 'zApFluxErr', 'zApFillFac',
+            'zApRadius', 'zKronFlux', 'zKronFluxErr', 'zKronRad', 'zexpTime',
+            'zExtNSigma', 'zsky', 'zskyErr', 'zzp', 'zPlateScale',
+            'yippDetectID', 'ystackDetectID', 'ystackImageID', 'yra', 'ydec',
+            'yraErr', 'ydecErr', 'yEpoch', 'yPSFMag', 'yPSFMagErr', 'yApMag',
+            'yApMagErr', 'yKronMag', 'yKronMagErr', 'yinfoFlag', 'yinfoFlag2',
+            'yinfoFlag3', 'ynFrames', 'yxPos', 'yyPos', 'yxPosErr', 'yyPosErr',
+            'ypsfMajorFWHM', 'ypsfMinorFWHM', 'ypsfTheta', 'ypsfCore',
+            'ypsfLikelihood', 'ypsfQf', 'ypsfQfPerfect', 'ypsfChiSq',
+            'ymomentXX', 'ymomentXY', 'ymomentYY', 'ymomentR1', 'ymomentRH',
+            'yPSFFlux', 'yPSFFluxErr', 'yApFlux', 'yApFluxErr', 'yApFillFac',
+            'yApRadius', 'yKronFlux', 'yKronFluxErr', 'yKronRad', 'yexpTime',
+            'yExtNSigma', 'ysky', 'yskyErr', 'yzp', 'yPlateScale', 'distance',
+            'NED_name', 'NED_type', 'NED_vel', 'NED_redshift', 'NED_mag',
+            'i-z', 'g-r', 'r-i', 'g-i', 'z-y', 'g-rErr', 'r-iErr', 'i-zErr',
+            'z-yErr', 'gApMag_gKronMag', 'rApMag_rKronMag', 'iApMag_iKronMag',
+            'zApMag_zKronMag', 'yApMag_yKronMag', '7DCD', 'class', 'dist/DLR',
+            'dist', 'TransientClass', 'TransientRA', 'TransientDEC',
+            'TransientDiscoveryDate', 'TransientDiscoveryMag',
+            'TransientRedshift', 'TransientDiscoveryYear', 'Transient AltName',
+            'host_logmass', 'host_logmass_min', 'host_logmass_max',
+            'Hubble Residual', 'TransientName']
         df = pd.DataFrame(columns = colnames)
-        df.to_csv(install_path + "/database/GHOST.csv",index=False)
+        df.to_csv(installpath + "/database/GHOST.csv",index=False)
         if verbose:
             print("Successfully created dummy database.\n")
 
@@ -180,8 +182,8 @@ def remove_prefix(text, prefix):
 #          If the supernova is currently in the
 #          database, return the database object.
 #          If not found, return None
-def getDBHostFromTransientCoords(transientCoords):
-    fullTable = fullData()
+def getDBHostFromTransientCoords(transientCoords, GHOSTpath=''):
+    fullTable = fullData(GHOSTpath)
     notFound = []
     host_DF = None
     hostList = []
@@ -216,8 +218,8 @@ def getDBHostFromTransientCoords(transientCoords):
 #          If the supernova is currently in the
 #          database, return the database object.
 #          If no host is found, return None
-def getDBHostFromTransientName(SNNames):
-    fullTable = fullData()
+def getDBHostFromTransientName(SNNames, GHOSTpath=''):
+    fullTable = fullData(GHOSTpath)
     allHosts = []
     notFound = []
     host_DF = None
@@ -249,8 +251,8 @@ def getDBHostFromTransientName(SNNames):
 #          If the supernova is currently in the
 #          database, return the database object.
 #          If no host is found, return None
-def getHostFromHostName(hostNames):
-    fullTable = fullData()
+def getHostFromHostName(hostNames, GHOSTpath=''):
+    fullTable = fullData(GHOSTpath)
     possibleNames = []
 
     for name in hostNames:
@@ -264,8 +266,8 @@ def getHostFromHostName(hostNames):
         print("Sorry, no hosts were found in our database!\n")
     return host
 
-def getHostFromHostCoords(hostCoords):
-    fullTable = fullData()
+def getHostFromHostCoords(hostCoords, GHOSTpath=''):
+    fullTable = fullData(GHOSTpath)
     c2 = SkyCoord(fullTable['raMean']*u.deg, fullTable['decMean']*u.deg, frame='icrs')
     host = []
     for hostCoord in hostCoords:
@@ -322,8 +324,8 @@ def getTransientStatsFromHostName(hostName):
 # host of a previously identified transient, using
 # the pipeline outlined above.
 # inputs - the coordinates of the transient to search
-def getHostStatsFromTransientCoords(transientCoordsList):
-    fullTable = fullData()
+def getHostStatsFromTransientCoords(transientCoordsList, GHOSTpath=''):
+    fullTable = fullData(GHOSTpath)
     names = []
     for transientCoords in transientCoordsList:
         c2 = SkyCoord(fullTable['TransientRA']*u.deg, fullTable['TransientDEC']*u.deg, frame='icrs')
@@ -339,10 +341,10 @@ def getHostStatsFromTransientCoords(transientCoordsList):
 # host of a previously identified transient, using
 # the pipeline outlined above.
 # inputs - the coordinates of the transient to search
-def getHostStatsFromTransientName(SNName):
+def getHostStatsFromTransientName(SNName, GHOSTpath=''):
     SNName = np.array(SNName)
-    fullTable = fullData()
-    host, notFound = getDBHostFromTransientName(SNName)
+    fullTable = fullData(GHOSTpath)
+    host, notFound = getDBHostFromTransientName(SNName, GHOSTpath)
     if host is not None:
         for idx, row in host.iterrows():
             if np.unique(row['NED_name']) != "":
@@ -355,10 +357,6 @@ def getHostStatsFromTransientName(SNName):
             print("PS1 rMag: %.2f"%row['rApMag'])
             print("g-r          r-i          i-z")
             print("%.2f+/-%.3f   %.2f+/-%.3f   %.2f+/-%.3f"%(row['g-r'],row['g-rErr'], row['r-i'], row['r-iErr'], row['i-z'], row['i-zErr']))
-        #    print("g-r: %.2f."%host['g-r'].values[0])
-        #    print("r-i: %.2f."%host['r-i'].values[0])
-        #    print("i-z: %.2f."%host['i-z'].values[0])
-            #print("There are %i supernovae associated with this object.\n"%len(host))
             print("Associated supernovae: ")
             if np.unique(row['NED_name']) != "":
                 tempHost = fullTable[fullTable['NED_name'] == row['NED_name']]
@@ -375,12 +373,12 @@ def getHostStatsFromTransientName(SNName):
 # fits file with radius rad, and plots the image.
 # inputs
 # outputs
-def getHostImage(transientName='', band="grizy", rad=60, save=0):
+def getHostImage(transientName='', band="grizy", rad=60, save=0, GHOSTpath=''):
     if transientName == '':
         print("Error! Please enter a supernova!\n")
         return
-    fullTable = fullData()
-    host, notFound = getDBHostFromTransientName(transientName)
+    fullTable = fullData(GHOSTpath)
+    host, notFound = getDBHostFromTransientName(transientName, GHOSTpath)
     if host is not None:
         host.reset_index(drop=True, inplace=True)
         tempSize = int(4*float(rad))
@@ -439,8 +437,8 @@ def getHostSpectra(SNname, path):#
 # within a certain radius, returned as a pandas dataframe
 # inputs location, in astropy coordinates, and radius in arcsec
 # outputs the data frame of all nearby pairs
-def coneSearchPairs(coord, radius):
-    fullTable = fullData()
+def coneSearchPairs(coord, radius, GHOSTpath=''):
+    fullTable = fullData(GHOSTpath)
     c2 = SkyCoord(fullTable['TransientRA']*u.deg, fullTable['TransientDEC']*u.deg, frame='icrs')
     sep = np.array(coord.separation(c2).arcsec)
     hosts = None
@@ -453,13 +451,17 @@ def coneSearchPairs(coord, radius):
 # Returns the full table of data
 # inputs: none
 # outputs: the full GHOST database
-def fullData():
-    install_path = os.getenv('GHOST_PATH')
-    if not install_path:
-    	install_path = astro_ghost.__file__
-    	install_path = install_path.split("/")[:-1]
-    	install_path = "/".join(install_path)
-    fullTable = pd.read_csv(install_path+"/database/GHOST.csv")
+def fullData(GHOSTpath=''):
+    if not GHOSTpath:
+        GHOSTpath = os.getenv('GHOST_PATH')
+        if not GHOSTpath:
+            try:
+                GHOSTpath = astro_ghost.__file__
+                GHOSTpath = GHOSTpath.split("/")[:-1]
+                GHOSTpath = "/".join(GHOSTpath)
+            except:
+                print("Error! I don't know where you installed GHOST -- set GHOST_PATH as an environmental variable or pass in the GHOSTpath parameter.")
+    fullTable = pd.read_csv(GHOSTpath+"/database/GHOST.csv")
     return fullTable
 
 # The wrapper function for the
@@ -470,9 +472,9 @@ def fullData():
 #         the most likely host in PS1,
 #         with stats provided at
 #         printout
-def getTransientHosts(snName=[''], snCoord=[''], snClass=[''], verbose=0, starcut='normal', ascentMatch=False, px=800, savepath='./'):
- 
-    #if no names were passed in, add placeholder names for each transient in the search 
+def getTransientHosts(snName=[''], snCoord=[''], snClass=[''], verbose=0, starcut='normal', ascentMatch=False, px=800, savepath='./', GHOSTpath=''):
+
+    #if no names were passed in, add placeholder names for each transient in the search
     if snName == ['']:
         snName = []
         print("No transient names listed, adding placeholder names...")
@@ -491,7 +493,7 @@ def getTransientHosts(snName=[''], snCoord=[''], snClass=[''], verbose=0, starcu
     snName = [x.replace(" ", "") for x in snName]
     df_transients = pd.DataFrame({'Name':np.array(snName), 'snCoord':np.array(snCoord), 'snClass':np.array(snClass)})
 
-    tempHost1, notFoundNames = getDBHostFromTransientName(snName)
+    tempHost1, notFoundNames = getDBHostFromTransientName(snName, GHOSTpath)
     found_by_name = len(snName) - len(notFoundNames)
 
     if tempHost1 is None or len(notFoundNames) > 0:
@@ -502,7 +504,7 @@ def getTransientHosts(snName=[''], snCoord=[''], snClass=[''], verbose=0, starcu
 
         snCoord_remaining =  df_transients_remaining['snCoord'].values
 
-        tempHost2, notFoundCoords = getDBHostFromTransientCoords(snCoord_remaining);
+        tempHost2, notFoundCoords = getDBHostFromTransientCoords(snCoord_remaining, GHOSTpath);
         found_by_coord = len(snName) - len(notFoundCoords) - found_by_name
         if tempHost2 is None or len(notFoundCoords) > 0:
             if verbose:
@@ -557,8 +559,10 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle', ascentMa
     fn_SN = 'transients_%s.csv' % dateStr
     fn_Dict = fn_Host[:-4] + ".p"
     dir_name = fn_SN[:-4]
-    if not os.path.exists(savepath + dir_name):
-        os.makedirs(savepath + dir_name)
+    if not os.path.exists(savepath):
+        os.mkdir(savepath)
+        os.chmod(savepath, 0o777)
+    os.makedirs(savepath + dir_name)
     path = savepath+dir_name+'/'
     #create temp dataframe with RA and DEC corresponding to the transient
 
@@ -591,8 +595,8 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle', ascentMa
             temp.update(transient_dict[i+1])
     transient_dict = {k.replace(' ', ''): v for k, v in temp.items()}
 
-    host_DF_north = host_DF[host_DF['decMean']>-30].reset_index()
-    host_DF_south = host_DF[host_DF['decMean']<=-30].reset_index()
+    host_DF_north = host_DF[host_DF['decMean']>-30].reset_index(drop=True)
+    host_DF_south = host_DF[host_DF['decMean']<=-30].reset_index(drop=True)
 
     host_DF_north = makeCuts(host_DF_north, cuts, transient_dict)
 
@@ -723,7 +727,7 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle', ascentMa
 
     for tempPath in paths:
         if not os.path.exists(tempPath):
-            os.makedirs(tempPath)
+            os.mkdir(tempPath)
 
     #move tables to the tables directory, and printouts to the printouts directory
     printouts = glob.glob(path+'/*.txt')
@@ -737,5 +741,9 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle', ascentMa
         for t in tables:
             fn = remove_prefix(t, path)
             os.rename(t, tablePath+fn)
-
+    #remove if there's an extra index column
+    try:
+        del host_DF['index']
+    except:
+        pass
     return(host_DF)
